@@ -5,7 +5,6 @@ use Getopt::Long qw(:config posix_default bundling);
 use App::DubiousHTTP::Tests;
 use App::DubiousHTTP::Tests::Common;
 use App::DubiousHTTP::TestServer;
-use Net::PcapWriter;
 
 sub usage {
     print STDERR "ERROR: @_\n" if @_;
@@ -59,6 +58,8 @@ sub make_doc {
 ############################ create pcap files
 sub make_pcaps {
     my $base = shift;
+    eval { require Net::PcapWriter }
+	or die "cannot load Net::PcapWriter\n";
     -d $base or die "$base does not exist";
     for my $cat ( App::DubiousHTTP::Tests->categories ) {
 	$cat->TESTS or next;
@@ -95,7 +96,13 @@ sub serve {
 	    (?: / ([^\?]*))?
 	    (?: \? (.*))?
 	}x;
-	$_ //= '' for ($cat,$page,$spec,$qstring);
+	for ($cat,$page,$spec,$qstring) {
+	    $_ = '' if ! defined $_;
+	}
+
+	return App::DubiousHTTP::Tests->auto($cat,$page,$spec,$qstring,$rqhdr)
+	    if $auto;
+
 	if ( $page && $cat ) {
 	    for ( App::DubiousHTTP::Tests->categories ) {
 		$_->ID eq $cat or next;
@@ -113,9 +120,6 @@ sub serve {
 	    return "HTTP/1.0 200 ok\r\n$hdr\r\n$data";
 	}
 
-	return App::DubiousHTTP::Tests->auto($cat,$page,$spec,$rqhdr)
-	    if $auto;
-
 	if ( $cat ) {
 	    for ( App::DubiousHTTP::Tests->categories ) {
 		return $_->make_index_page($page,$spec,$rqhdr)
